| Title: | R MTC Jags 'Rcmdr' Plugin |
|---|---|
| Description: | Mixed Treatment Comparison is a methodology to compare directly and/or indirectly health strategies (drugs, treatments, devices). This package provides an 'Rcmdr' plugin to perform Mixed Treatment Comparison for binary outcome using BUGS code from Bristol University (Lu and Ades). |
| Authors: | Marcelo Goulart Correia <[email protected]> |
| Maintainer: | Marcelo Goulart Correia <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0-2 |
| Built: | 2026-04-03 04:53:25 UTC |
| Source: | https://github.com/cran/RcmdrPlugin.RMTCJags |
Mixed Treatment Comparison is a methodology to compare directly and/or indirectly health strategies (drugs, treatments, devices). This package provides an Rcmdr plug-in to perform Mixed Treatment Comparison for binary outcome using BUGS code from Bristol University (Lu and Ades).
| Package: | RcmdrPlugin.RMTCJags |
| Type: | Package |
| Version: | 1.01-1 |
| Date: | 2015-06-17 |
| License: | GPL (>= 2) |
Marcelo Goulart Correia <[email protected]>
Manual to build database for RcmdrPlugin.RMTCJags
Fixed Effect Model (FE Model), Random Effect Model (RE Model) Ignoring multi-arm trials and Random Effect Model (RE Model) for 2- and 3-arms trials:
A database with six (6) variables:
s -> Study index (Number)
t -> Treatment index (Number)
r -> Number of cases on the treatment
n -> Total population on the treatment
b -> Baseline treatment
m -> Arm index (Only needed on RE Model for 2- and 3-arms trials), where 1 is the baseline treatment and 2,..,n are for the other treatments
Each line on the database is a treatment of a trial (study), for example:
| s | t | r | n | b | m |
| 1 | 1 | 40 | 100 | 1 | 1 |
| 1 | 3 | 15 | 90 | 1 | 2 |
| 1 | 4 | 10 | 75 | 1 | 3 |
| ... | ... | ... | ... | ... | ... |
| 4 | 2 | 50 | 200 | 2 | 1 |
| 4 | 4 | 60 | 150 | 2 | 2 |
Random Effect Model (RE Model) for multi-arm trial:
A database with N*3 + 1 columns, where N is the highest number of arms from a trial collection.
t[1,..N,] -> Treatment index
r[1,..N,] -> Number of cases on the treatment
n[1,..N,] -> Total population on the treatment
na -> Number of arms on the study
Each line on the database is a trial. For example, if we collect 10 trials and after check them we have the biggest trial with 5 arms our database structure is:
| t[1,] | t[2,] | t[3,] | t[4,] | t[5,] | r[1,] | r[2,] | r[3,] | r[4,] | r[5,] | n[1,] | n[2,] | n[3,] | n[4,] | n[5,] | na |
| 1 | 2 | 3 | 4 | 5 | 20 | 30 | 10 | 5 | 14 | 100 | 90 | 80 | 110 | 50 | 5 |
| 1 | 3 | 4 | 5 | NA | 10 | 50 | 60 | 15 | NA | 150 | 200 | 340 | 165 | 1 | 4 |
| 2 | 4 | 5 | NA | NA | 40 | 70 | 80 | NA | NA | 70 | 190 | 500 | 1 | 1 | 3 |
| ... | ... | ... | ... | ... | ... | ... | ... | ... | ... | ... | ... | ... | ... | ... | ... |
| 3 | 4 | NA | NA | NA | 80 | 90 | NA | NA | NA | 250 | 580 | 1 | 1 | 1 | 2 |